==> beta1.7.tar.bz2: beta1.7/defines.h <==
//channel flags
#define FLAG_I					0x0000001
#define FLAG_N					0x0000002
#define FLAG_S					0x0000004
#define FLAG_M					0x0000008
#define FLAG_T					0x0000010
#define FLAG_R					0x0000020
#define FLAG_P					0x0000040
#define FLAG_Q					0x0000080

//user flags
#define HAS_A					0x0000001
#define HAS_D					0x0000002
#define HAS_O					0x0000004
#define HAS_F					0x0000008
#define HAS_M					0x0000010
#define HAS_N					0x0000020
#define HAS_S					0x0000040
#define HAS_T					0x0000080
#define HAS_V					0x0000100
#define HAS_Q					0x0000200
#define HAS_R					0x0000400
#define HAS_K					0x0000800
#define HAS_I					0x0001000
#define HAS_E					0x0002000
#define HAS_C					0x0004000
#define HAS_X					0x0008000
#define HAS_ALL					0x0010000 - 1

#define HAS_B                 	0x0020000
#define HAS_L					0x0040000
#define HAS_H					0x0080000

#define B_FLAGS					HAS_B | HAS_O | HAS_A | HAS_F | HAS_I | HAS_R | HAS_C | HAS_E
#define F_FLAGS					HAS_O | HAS_F
#define M_FLAGS					F_FLAGS | HAS_M | HAS_I
#define N_FLAGS					M_FLAGS | HAS_N | HAS_C | HAS_R
#define S_FLAGS					N_FLAGS | HAS_S
#define T_FLAGS					N_FLAGS | HAS_T
#define X_FLAGS					S_FLAGS | HAS_X | HAS_T

#define IS_OP                 	0x0100000
#define KICK_SENT				0x0200000
#define OP_SENT					0x0400000
#define BAN_SENT              	0x0800000
#define UNBAN_SENT				0x1000000
#define DEOP_SENT				0x2000000
#define NET_JOINED				0x4000000

#define ARG_MODES				"oblkeIv"
#define NONARG_MODES			"imntsp"

//inetconn flags
#define STATUS_CONNECTED		0x0000001
#define STATUS_REGISTERED		0x0000002
#define STATUS_SYNSENT			0x0000004
#define STATUS_OWNER			0x0000008
#define STATUS_BOT				0x0000010
#define STATUS_SILENT			0x0000020
#define STATUS_KLINED			0x0000040
#define STATUS_TELNET			0x0000080
#define STATUS_REDIR			0x0000100
#define STATUS_FILE				0x0000200

//chanlist flags
#define SET_TOPIC				0x0000001
#define JOIN_SENT				0x0000002

//other shit
#define MAX_LEN					4096
#define MAX_SERVERS				16
#define MAX_CHANNELS			32
#define GLOBAL					MAX_CHANNELS
#define MAX_HOSTS				64
#define MD5_HEXDIGEST_LEN		32
#define AUTHSTR_LEN				32
#define MAX_INT					0x7fffffff
#define MODES_PER_LINE			10

#define BOT_LEAF				1
#define BOT_SLAVE				2
#define BOT_MAIN				3

#define MK_OPS					1
#define MK_NONOPS				2
#define MK_ALL					3

#define BAN						0
#define EXEMPT					1
#define INVITE					2

#define OWNERS					STATUS_OWNER
#define FD_BOTS					STATUS_BOT

#define TCP_NODELAY				1

#define S_UL_UPLOAD_START		"USTART"
#define S_UL_UPLOAD_END			"UEND"
#define S_CHNICK				"CHNICK"
#define S_REGISTER				"REG"
#define S_UNKNOWN				"<?>"
#define S_SECRET				"-"
#define S_INVITE				"INV"
#define S_KEY					"KEY"
#define S_KEYRPL				"KEYRPL"
#define S_REOP					"REOP"
#define S_CYCLE					"CYCLE"

#define S_ADDUSER				"ADDUSER"
#define S_ADDHOST				"ADDHOST"
#define S_ADDBOT				"ADDBOT"
#define S_ADDCHAN				"ADDCHAN"

#define S_RMUSER				"RMUSER"
#define S_RMHOST				"RMHOST"
#define S_RMBOT					"RMBOT"
#define S_RMCHAN				"RMCHAN"

#define S_CHATTR				"CHATTR"
#define S_ULSAVE				"SAVE"
#define S_SN					"SN"
#define S_SET					"SET"
#define S_CHSET					"CHSET"
#define S_GCHSET				"GCHSET"
#define S_GETOP					"GETOP"
#define S_OP					"OP"
#define S_BOP					"BOP"
#define S_FOO					"FOO"
#define S_NICK					"NICK"
#define S_PASSWD				"PASSWD"
#define S_MKO					"MKO"
#define S_MKN					"MKN"
#define S_MKA					"MKA"
#define S_LIST					"LIST"
#define S_REDIR					"REDIR"
#define S_OREDIR				"OREDIR"
#define S_BJOIN					"BJOIN"
#define S_BQUIT					"BQUIT"
#define S_ADDR					"ADDR"
#define S_ULOK					"ULOK"
#define S_UNLINK				"UNLINK"
#define S_JUMP					"JMP"
#define S_JUMP6					"JMP6"
#define S_COMEON				"CO"
#define S_BIDLIMIT				"BL"
#define S_UNBANME				"UBM"
#define S_RESET					"RST"
#define S_RDIE					"RDIE"
#define S_NAMES					"N"
#define S_PSOTGET				"PSOTGET"
#define S_RESTART				"RESTART"

#define S_NOPERM				strerror(EACCES)
#define S_VERSION				"0.1.7"
#define S_BOTNAME				"psotnic"
#define S_COPYRIGHT				"Copyright (C) 2003-2004 Grzegorz Rusin <pks@irc.pl, gg:1569230>"

#define DIE_REASON				"Taking the blue pill"
#define DIE_REASON2				"told me to take the blue pill"

#define maskstrip(__mask, __nick, __ident, __host)			\
{															\
	char *__a = strchr(__mask, '!');						\
   	char *__b = strchr(__mask, '@');						\
   	mem_strncpy(__nick, __mask, (int) abs(__mask-__a)+1);	\
   	mem_strncpy(__ident, __a+1, (int) abs(__a - __b));		\
   	mem_strcpy(__host, __b+1);								\
}

#define userMask(__mask, __user)							\
{															\
	strcpy(__mask, __user->nick);							\
	strcat(__mask, "!");									\
	strcat(__mask, __user->ident);							\
	strcat(__mask, "@");									\
	strcat(__mask, __user->host);							\
}

#define set(__a, __b)			if(!(__a & __b)) __a += __b
#define unset(__a, __b)			if(__a & __b) __a -= __b
#define debug()					printf("[D] [%s:%d] %s(): %s\n", __FILE__, __LINE__, __FUNCTION__, strerror(errno))
#define	bk						printf("### %s(): %s:%d\n", __FUNCTION__, __FILE__, __LINE__)
#define ircstrip(str)			(str[0] == ':') ? (str+1) : (str)
#define match(mask, str)		!ircd_match(mask, str)
#define strcmp(s1, s2)			ircd_strcmp(s1, s2)
#define strncmp(s1, s2, n)		ircd_strncmp(s1, s2, n)
#define strcasecmp(s1, s2)		ircd_strcmp(s1, s2)
#define strncasecmp(s1, s2, n)	ircd_strncmp(s1, s2, n)
#define actionPenalty(x)		(x == 4 ? 14 : x == 3 ? 10 : x == 2 ? 7 : x == 1 ? 4 : 0)


#define VER_NONE		0
#define VER_PSOTNIC		1
#define VER_IRSSI		2
#define VER_EPIC		3
#define VER_LICE		4
#define VER_BITCHX		5
#define VER_DZONY		6
#define VER_LUZIK		7
#define VER_MIRC		8

#ifdef HAVE_DEBUG
	#define DEBUG(x)	if(set.debug) x
#else
	#define DEBUG(x)
#endif

==> beta2.0rc10.tar.bz2: beta2.0rc10/defines.h <==
//channel flags
#define FLAG_I					0x0000001
#define FLAG_N					0x0000002
#define FLAG_S					0x0000004
#define FLAG_M					0x0000008
#define FLAG_T					0x0000010
#define FLAG_R					0x0000020
#define FLAG_P					0x0000040
#define FLAG_Q					0x0000080
#define ILOCK_SENT				0x0000100
#define IUNLOCK_SENT			0x0000200
#define KLICK_SENT				0x0000400
#define KUNLOCK_SENT			0x0000800

//user flags
#define HAS_A					0x0000001
#define HAS_D					0x0000002
#define HAS_O					0x0000004
#define HAS_F					0x0000008
#define HAS_M					0x0000010
#define HAS_N					0x0000020
#define HAS_S					0x0000040
#define HAS_T					0x0000080
#define HAS_V					0x0000100
#define HAS_Q					0x0000200
#define HAS_R					0x0000400
#define HAS_K					0x0000800
#define HAS_I					0x0001000
#define HAS_E					0x0002000
#define HAS_C					0x0004000
#define HAS_X					0x0008000
#define HAS_ALL					0x0010000 - 1

#define HAS_B                 	0x0020000
#define HAS_L					0x0040000
#define HAS_H					0x0080000
#define HAS_P					0x8000000

#define B_FLAGS					HAS_B | HAS_O | HAS_A | HAS_F | HAS_I | HAS_R | HAS_C | HAS_E
#define F_FLAGS					HAS_O | HAS_F
#define M_FLAGS					F_FLAGS | HAS_M | HAS_I
#define N_FLAGS					M_FLAGS | HAS_N | HAS_C | HAS_R
#define S_FLAGS					N_FLAGS | HAS_S
#define T_FLAGS					N_FLAGS | HAS_T
#define X_FLAGS					S_FLAGS | HAS_X | HAS_T

#define IS_OP                 	0x0100000
#define KICK_SENT				0x0200000
#define OP_SENT					0x0400000
#define BAN_SENT              	0x0800000
#define UNBAN_SENT				0x1000000
#define DEOP_SENT				0x2000000
#define NET_JOINED				0x4000000

#define ARG_MODES				"oblkeIv"
#define NONARG_MODES			"imntsp"

//inetconn flags
#define STATUS_CONNECTED		0x0000001
#define STATUS_REGISTERED		0x0000002
#define STATUS_SYNSENT			0x0000004
#define STATUS_OWNER			0x0000008
#define STATUS_BOT				0x0000010
#define STATUS_SILENT			0x0000020
#define STATUS_KLINED			0x0000040
#define STATUS_TELNET			0x0000080
#define STATUS_REDIR			0x0000100
#define STATUS_FILE				0x0000200
#define STATUS_SOCKS5			0x0000400
#define STATUS_SOCKS5_CONNECTED	0x0000800
#define STATUS_NOECHO			0x0001000

//chanlist flags
#define SET_TOPIC				0x0000001
#define JOIN_SENT				0x0000002
#define PRIVATE_CHAN			0x0000004
#define WHO_SENT				0x0000008

//other shit
#define MAX_LEN					4096
#define MAX_SERVERS				16
#define MAX_CHANNELS			32
#define GLOBAL					MAX_CHANNELS
#define MAX_HOSTS				64
#define MD5_HEXDIGEST_LEN		32
#define AUTHSTR_LEN				32
#define MAX_INT					0x7fffffff
#define MODES_PER_LINE			10
#define MAX_HANDLE_LEN			9

#define BOT_LEAF				1
#define BOT_SLAVE				2
#define BOT_MAIN				3

#define MK_OPS					1
#define MK_NONOPS				2
#define MK_ALL					3

#define BAN						0
#define EXEMPT					1
#define INVITE					2

#define OWNERS					STATUS_OWNER
#define FD_BOTS					STATUS_BOT

#define TCP_NODELAY				1

#define S_UL_UPLOAD_START		"00"
#define S_UL_UPLOAD_END			"01"
#define S_CHNICK				"02"
#define S_REGISTER				"03"
#define S_SECRET				"04"
#define S_INVITE				"05"
#define S_KEY					"06"
#define S_KEYRPL				"07"
#define S_REOP					"08"
#define S_CYCLE					"09"

#define S_ADDUSER				"11"
#define S_ADDHOST				"12"
#define S_ADDBOT				"13"
#define S_ADDCHAN				"14"

#define S_RMUSER				"15"
#define S_RMHOST				"16"
#define S_RMBOT					"17"
#define S_RMCHAN				"18"

#define S_CHATTR				"19"
#define S_ULSAVE				"20"
#define S_SN					"21"
#define S_SET					"22"
#define S_CHSET					"23"
#define S_GCHSET				"24"
#define S_GETOP					"25"
#define S_OP					"26"
#define S_BOP					"27"
#define S_FOO					"28"
#define S_NICK					"29"
#define S_PASSWD				"30"
#define S_MKO					"31"
#define S_MKN					"32"
#define S_MKA					"33"
#define S_LIST					"34"
#define S_REDIR					"35"
#define S_OREDIR				"36"
#define S_BJOIN					"37"
#define S_BQUIT					"38"
#define S_ADDR					"39"
#define S_ULOK					"40"
#define S_UNLINK				"41"
#define S_JUMP					"42"
#define S_JUMP6					"43"
#define S_COMEON				"44"
#define S_BIDLIMIT				"45"
#define S_UNBANME				"46"
#define S_RESET					"47"
#define S_RDIE					"48"
#define S_NAMES					"49"
#define S_PSOTGET				"50"
#define S_RESTART				"51"
#define S_RJOIN					"52"
#define S_RPART					"53"
#define S_JUMPS5				"54"
#define S_PROXYHOST				"55"
#define S_CHHANDLE				"56"
#define S_ADDINFO				"57"

#define S_NOPERM				strerror(EACCES)
#define S_VERSION				"0.2.0rc10"

#define S_BOTNAME				"psotnic"
#define S_COPYRIGHT				"Copyright (C) 2003-2004 Grzegorz Rusin <pks@irc.pl, gg:1569230>"

#define DIE_REASON				"Taking the blue pill"
#define DIE_REASON2				"told me to take the blue pill"

#define maskstrip(__mask, __nick, __ident, __host)			\
{															\
	char *__a = strchr(__mask, '!');						\
   	char *__b = strchr(__mask, '@');						\
   	mem_strncpy(__nick, __mask, (int) abs(__mask-__a)+1);	\
   	mem_strncpy(__ident, __a+1, (int) abs(__a - __b));		\
   	mem_strcpy(__host, __b+1);								\
}

#define userMask(__mask, __user)							\
{															\
	strcpy(__mask, __user->nick);							\
	strcat(__mask, "!");									\
	strcat(__mask, __user->ident);							\
	strcat(__mask, "@");									\
	strcat(__mask, __user->host);							\
}

#define set(__a, __b)			if(!(__a & __b)) __a += __b
#define unset(__a, __b)			if(__a & __b) __a -= __b
#define debug()					printf("[D] [%s:%d] %s(): %s\n", __FILE__, __LINE__, __FUNCTION__, strerror(errno))
#define	bk						printf("### %s(): %s:%d\n", __FUNCTION__, __FILE__, __LINE__)
#define ircstrip(str)			(str[0] == ':') ? (str+1) : (str)
#define match(mask, str)		!ircd_match(mask, str)
#define strcmp(s1, s2)			ircd_strcmp(s1, s2)
#define strncmp(s1, s2, n)		ircd_strncmp(s1, s2, n)
#define strcasecmp(s1, s2)		ircd_strcmp(s1, s2)
#define strncasecmp(s1, s2, n)	ircd_strncmp(s1, s2, n)
#define actionPenalty(x)		(x == 4 ? 14 : x == 3 ? 10 : x == 2 ? 7 : x == 1 ? 4 : 0)


#define VER_NONE		0
#define VER_PSOTNIC		1
#define VER_IRSSI		2
#define VER_EPIC		3
#define VER_LICE		4
#define VER_BITCHX		5
#define VER_DZONY		6
#define VER_LUZIK		7
#define VER_MIRC		8

#ifdef HAVE_DEBUG
	#define DEBUG(x)	if(set.debug) x
#else
	#define DEBUG(x)
#endif
